@@ -96,6 +96,8 @@ pub mod paginated_octo_print_settings_list;
 pub use self::paginated_octo_print_settings_list::PaginatedOctoPrintSettingsList;
 pub mod paginated_octo_printer_profile_list;
 pub use self::paginated_octo_printer_profile_list::PaginatedOctoPrinterProfileList;
+pub mod paginated_polymorphic_command_list;
+pub use self::paginated_polymorphic_command_list::PaginatedPolymorphicCommandList;
 pub mod paginated_polymorphic_event_list;
 pub use self::paginated_polymorphic_event_list::PaginatedPolymorphicEventList;
 pub mod paginated_public_key_list;
@@ -130,6 +132,10 @@ pub mod patched_system_info_request;
 pub use self::patched_system_info_request::PatchedSystemInfoRequest;
 pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
+pub mod polymorphic_command;
+pub use self::polymorphic_command::PolymorphicCommand;
+pub mod polymorphic_command_request;
+pub use self::polymorphic_command_request::PolymorphicCommandRequest;
 pub mod polymorphic_event;
 pub use self::polymorphic_event::PolymorphicEvent;
 pub mod polymorphic_event_request;
@@ -158,6 +164,14 @@ pub mod user;
 pub use self::user::User;
 pub mod user_request;
 pub use self::user_request::UserRequest;
+pub mod web_rtc_command;
+pub use self::web_rtc_command::WebRtcCommand;
+pub mod web_rtc_command_event_name_enum;
+pub use self::web_rtc_command_event_name_enum::WebRtcCommandEventNameEnum;
+pub mod web_rtc_command_model_enum;
+pub use self::web_rtc_command_model_enum::WebRtcCommandModelEnum;
+pub mod web_rtc_command_request;
+pub use self::web_rtc_command_request::WebRtcCommandRequest;
 pub mod web_rtc_event;
 pub use self::web_rtc_event::WebRtcEvent;
 pub mod web_rtc_event_model;
